@@ -1,3 +1,11 @@
+# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only
+# under the conditions described in the aforementioned license.  The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+# Thanks for using Enthought open source!
 """ The Envisage core plugin. """
 
 
@@ -171,8 +179,8 @@ class CorePlugin(Plugin):
         has been retracted.
 
         """
-
-        map(self._register_service_offer, event.added)
+        for service in event.added:
+            self._register_service_offer(service)
 
         return
 
@@ -233,7 +241,7 @@ class CorePlugin(Plugin):
         """ Create a category class load hook. """
 
         # Local imports.
-        from class_load_hook import ClassLoadHook
+        from .class_load_hook import ClassLoadHook
 
         def import_and_add_category(cls):
             """ Import a category and add it to a class.
@@ -282,7 +290,7 @@ class CorePlugin(Plugin):
     def _register_service_offers(self, service_offers):
         """ Register a list of service offers. """
 
-        return map(self._register_service_offer, service_offers)
+        return list(map(self._register_service_offer, service_offers))
 
     def _register_service_offer(self, service_offer):
         """ Register a service offer. """
