@@ -1,3 +1,11 @@
+# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only
+# under the conditions described in the aforementioned license.  The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+# Thanks for using Enthought open source!
 """ A binding between a trait on an object and an extension point. """
 
 
@@ -8,7 +16,7 @@ import weakref
 from traits.api import Any, HasTraits, Instance, Str, Undefined
 
 # Local imports.
-from i_extension_registry import IExtensionRegistry
+from .i_extension_registry import IExtensionRegistry
 
 
 class ExtensionPointBinding(HasTraits):
@@ -73,7 +81,7 @@ class ExtensionPointBinding(HasTraits):
         """ Trait initializer. """
 
         # fixme: Sneaky global!!!!!
-        from extension_point import ExtensionPoint
+        from .extension_point import ExtensionPoint
 
         return ExtensionPoint.extension_registry
 
@@ -141,7 +149,7 @@ class ExtensionPointBinding(HasTraits):
         value = self.extension_registry.get_extensions(self.extension_point_id)
         traits = {self.trait_name : value}
 
-        self.obj.set(trait_change_notify=notify, **traits)
+        self.obj.trait_set(trait_change_notify=notify, **traits)
 
         return
 
