@@ -1,3 +1,11 @@
+# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only
+# under the conditions described in the aforementioned license.  The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+# Thanks for using Enthought open source!
 """ The application interface. """
 
 
@@ -6,11 +14,11 @@ from apptools.preferences.api import IPreferences
 from traits.api import Event, Instance, Str, VetoableEvent
 
 # Local imports.
-from i_extension_registry import IExtensionRegistry
-from i_import_manager import IImportManager
-from i_plugin_manager import IPluginManager
-from i_service_registry import IServiceRegistry
-from application_event import ApplicationEvent
+from .i_extension_registry import IExtensionRegistry
+from .i_import_manager import IImportManager
+from .i_plugin_manager import IPluginManager
+from .i_service_registry import IServiceRegistry
+from .application_event import ApplicationEvent
 
 
 class IApplication(
