@@ -1,28 +1,37 @@
+# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only
+# under the conditions described in the aforementioned license.  The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+# Thanks for using Enthought open source!
 """ A simple plugin manager implementation. """
 
 
 from fnmatch import fnmatch
 import logging
 
-from traits.api import Event, HasTraits, Instance, List, Str, implements
+from traits.api import Event, HasTraits, Instance, List, Str, provides
 
-from i_application import IApplication
-from i_plugin import IPlugin
-from i_plugin_manager import IPluginManager
-from plugin_event import PluginEvent
+from .i_application import IApplication
+from .i_plugin import IPlugin
+from .i_plugin_manager import IPluginManager
+from .plugin_event import PluginEvent
 
 
 
 logger = logging.getLogger(__name__)
 
 
+@provides(IPluginManager)
 class PluginManager(HasTraits):
     """ A simple plugin manager implementation.
 
     This implementation manages an explicit collection of plugin instances,
     e.g::
 
-        plugin_manager = PlugunManager(
+        plugin_manager = PluginManager(
              plugins = [
                  MyPlugin(),
                  YourPlugin()
@@ -31,10 +40,8 @@ class PluginManager(HasTraits):
 
     Plugins can be added and removed after construction time via the methods
     'add_plugin' and 'remove_plugin'.
-    
-    """
 
-    implements(IPluginManager)
+    """
 
     #### 'IPluginManager' protocol #############################################
 
@@ -96,7 +103,7 @@ class PluginManager(HasTraits):
 
             if self._include_plugin(plugin.id)
         ]
-        
+
         return iter(plugins)
 
     #### 'IPluginManager' protocol #############################################
@@ -116,7 +123,7 @@ class PluginManager(HasTraits):
             if plugin_id == plugin.id:
                 if not self._include_plugin(plugin.id):
                     plugin = None
-                    
+
                 break
 
         else:
@@ -135,7 +142,8 @@ class PluginManager(HasTraits):
     def start(self):
         """ Start the plugin manager. """
 
-        map(lambda plugin: self.start_plugin(plugin), self._plugins)
+        for plugin in self._plugins:
+            self.start_plugin(plugin)
 
         return
 
@@ -160,7 +168,8 @@ class PluginManager(HasTraits):
         stop_order = self._plugins[:]
         stop_order.reverse()
 
-        map(lambda plugin: self.stop_plugin(plugin), stop_order)
+        for plugin in stop_order:
+            self.stop_plugin(plugin)
 
         return
 
@@ -207,7 +216,7 @@ class PluginManager(HasTraits):
         """
 
         return self._is_included(plugin_id) and not self._is_excluded(plugin_id)
-    
+
     #### Private protocol ######################################################
 
     def _is_excluded(self, plugin_id):
