@@ -1,3 +1,11 @@
+# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only
+# under the conditions described in the aforementioned license.  The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+# Thanks for using Enthought open source!
 import logging
 
 from apptools.io.api import File
@@ -5,7 +13,7 @@ from pyface.api import FileDialog, OK
 from pyface.action.api import Action
 from traits.api import Any
 
-from editor.text_editor import TextEditor
+from .editor.text_editor import TextEditor
 
 logger = logging.getLogger(__name__)
 
