@@ -1,3 +1,11 @@
+# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only
+# under the conditions described in the aforementioned license.  The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+# Thanks for using Enthought open source!
 """ A resource protocol for a local file system. """
 
 
@@ -5,18 +13,17 @@
 import errno
 
 # Enthought library imports.
-from traits.api import HasTraits, implements
+from traits.api import HasTraits, provides
 
 # Local imports.
-from i_resource_protocol import IResourceProtocol
-from no_such_resource_error import NoSuchResourceError
+from .i_resource_protocol import IResourceProtocol
+from .no_such_resource_error import NoSuchResourceError
 
 
+@provides(IResourceProtocol)
 class FileResourceProtocol(HasTraits):
     """ A resource protocol for a local file system. """
 
-    implements(IResourceProtocol)
-
     ###########################################################################
     # 'IResourceProtocol' interface.
     ###########################################################################
@@ -27,9 +34,9 @@ class FileResourceProtocol(HasTraits):
         # Opened in binary mode to be consistent with package resources. This
         # means, for example, that line-endings will not be converted.
         try:
-            f = file(address, 'rb')
+            f = open(address, 'rb')
 
-        except IOError, e:
+        except IOError as e:
             if e.errno == errno.ENOENT:
                 raise NoSuchResourceError(address)
 
