@@ -1,3 +1,11 @@
+# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only
+# under the conditions described in the aforementioned license.  The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+# Thanks for using Enthought open source!
 """ The *definition* of a group in a tool bar or menu. """
 
 
@@ -5,7 +13,7 @@
 from traits.api import Bool, Str
 
 # Local imports.
-from location import Location
+from .location import Location
 
 
 class Group(Location):
