@@ -1,3 +1,11 @@
+# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only
+# under the conditions described in the aforementioned license.  The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+# Thanks for using Enthought open source!
 # Enthought library imports.
 from traits.api import Bool, HasTraits, Instance, List, Unicode, \
     on_trait_change
@@ -5,8 +13,8 @@ from traitsui.api import Item, Handler, ListEditor, View
 from pyface.tasks.topological_sort import before_after_sort
 
 # Local imports.
-from preferences_category import PreferencesCategory
-from preferences_pane import PreferencesPane
+from .preferences_category import PreferencesCategory
+from .preferences_pane import PreferencesPane
 
 
 class PreferencesTab(HasTraits):
